@@ -1,6 +1,6 @@
 import importlib
 
-from fastapi_cli_command.helpers.load_module import ModuleHelper
+from fastapi_cli_command.helpers import ModuleHelper
 
 
 class FastAPICli:
